# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/00-core.ipynb (unless otherwise specified).

__all__ = []

# Cell
from loguru import logger
import sys

logger.remove()
logger.add(sink=sys.stderr, level='INFO')